@@ -27,6 +27,15 @@ from googlecloudsdk.core import exceptions
 import six
 
 
+REDEPLOY_GPU_MESSAGE = (
+    'You could deploy using GPUs without zonal redundancy instead.'
+)
+REDEPLOY_GPU_WITH_FLAG_MESSAGE = (
+    'You could deploy with --no-gpu-zonal-redundancy flag attached to your'
+    ' command.\n'
+)
+
+
 class SelfDocumentingError(exceptions.Error):
   """An error that uses its own docstring as its message if no message given.
 
@@ -154,14 +163,6 @@ class NoTLSError(exceptions.Error):
 class HttpError(exceptions_util.HttpException):
   """More prettily prints apitools HttpError."""
 
-  REDEPLOY_ERROR_MESSAGE = (
-      'You could deploy using GPUs without zonal redundancy instead.'
-  )
-  REDEPLOY_WITH_FLAG_ERROR_MESSAGE = (
-      'You could deploy with --no-gpu-zonal-redundancy flag attached to your'
-      ' command.\n'
-  )
-
   def __init__(self, error):
     super(HttpError, self).__init__(error)
     if self.payload.field_violations:
@@ -169,15 +170,12 @@ class HttpError(exceptions_util.HttpException):
           '{0}: {{field_violations.{0}}}'.format(k)
           for k in self.payload.field_violations.keys()
       ])
-      # Temporarily replace the deploy with NZR message with gcloud flag.
+      # Replace the deploy with NZR message with gcloud flag.
       for k in self.payload.field_violations.keys():
-        if self.REDEPLOY_ERROR_MESSAGE in self.payload.field_violations[k]:
+        if REDEPLOY_GPU_MESSAGE in self.payload.field_violations[k]:
           self.payload.field_violations[k] = self.payload.field_violations[
               k
-          ].replace(
-              self.REDEPLOY_ERROR_MESSAGE,
-              self.REDEPLOY_WITH_FLAG_ERROR_MESSAGE,
-          )
+          ].replace(REDEPLOY_GPU_MESSAGE, REDEPLOY_GPU_WITH_FLAG_MESSAGE)
 
 
 class FieldMismatchError(exceptions.Error):
@@ -324,3 +322,14 @@ class RequiredImageArgumentException(c_exceptions.RequiredArgumentException):
             ', '.join(containers)
         ),
     )
+
+
+class NoGrpcInstalledError(exceptions.Error):
+  """Error that occurs when the gRPC module is not installed."""
+
+  def __init__(self):
+    super(NoGrpcInstalledError, self).__init__(
+        'Please ensure that the gRPC module is installed and the environment '
+        'is correctly configured. Run `sudo pip3 install grpcio` and set the '
+        'environment variable CLOUDSDK_PYTHON_SITEPACKAGES=1.'
+    )
