@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2023 Google LLC
+# Copyright 2024 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,6 +18,8 @@ from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers_async
+from google.api_core import exceptions as core_exceptions
+from google.api_core import retry_async as retries
 from google.auth import credentials as ga_credentials   # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
@@ -25,6 +27,7 @@ import grpc                        # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.api import httpbody_pb2  # type: ignore
+from google.longrunning import operations_pb2 # type: ignore
 from googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types import prediction_service
 from .base import PredictionServiceTransport, DEFAULT_CLIENT_INFO
 from .grpc import PredictionServiceGrpcTransport
@@ -64,7 +67,6 @@ class PredictionServiceGrpcAsyncIOTransport(PredictionServiceTransport):
                 the credentials from the environment.
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
-                This argument is ignored if ``channel`` is provided.
             scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                 service. These are only used when credentials are not specified and
                 are passed to :func:`google.auth.default`.
@@ -92,7 +94,7 @@ class PredictionServiceGrpcAsyncIOTransport(PredictionServiceTransport):
             credentials: Optional[ga_credentials.Credentials] = None,
             credentials_file: Optional[str] = None,
             scopes: Optional[Sequence[str]] = None,
-            channel: Optional[aio.Channel] = None,
+            channel: Optional[Union[aio.Channel, Callable[..., aio.Channel]]] = None,
             api_mtls_endpoint: Optional[str] = None,
             client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
             ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
@@ -106,21 +108,24 @@ class PredictionServiceGrpcAsyncIOTransport(PredictionServiceTransport):
 
         Args:
             host (Optional[str]):
-                 The hostname to connect to.
+                 The hostname to connect to (default: 'aiplatform.googleapis.com').
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-                This argument is ignored if ``channel`` is provided.
+                This argument is ignored if a ``channel`` instance is provided.
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
-                This argument is ignored if ``channel`` is provided.
+                This argument is ignored if a ``channel`` instance is provided.
             scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                 service. These are only used when credentials are not specified and
                 are passed to :func:`google.auth.default`.
-            channel (Optional[aio.Channel]): A ``Channel`` instance through
-                which to make calls.
+            channel (Optional[Union[aio.Channel, Callable[..., aio.Channel]]]):
+                A ``Channel`` instance through which to make calls, or a Callable
+                that constructs and returns one. If set to None, ``self.create_channel``
+                is used to create the channel. If a Callable is given, it will be called
+                with the same arguments as used in ``self.create_channel``.
             api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                 If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
@@ -130,11 +135,11 @@ class PredictionServiceGrpcAsyncIOTransport(PredictionServiceTransport):
                 private key bytes, both in PEM format. It is ignored if
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for the grpc channel. It is ignored if ``channel`` is provided.
+                for the grpc channel. It is ignored if a ``channel`` instance is provided.
             client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 A callback to provide client certificate bytes and private key bytes,
                 both in PEM format. It is used to configure a mutual TLS channel. It is
-                ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
+                ignored if a ``channel`` instance or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
             client_info (google.api_core.gapic_v1.client_info.ClientInfo):
@@ -160,7 +165,7 @@ class PredictionServiceGrpcAsyncIOTransport(PredictionServiceTransport):
         if client_cert_source:
             warnings.warn("client_cert_source is deprecated", DeprecationWarning)
 
-        if channel:
+        if isinstance(channel, aio.Channel):
             # Ignore credentials if a channel was passed.
             credentials = False
             # If a channel was explicitly provided, set it.
@@ -200,7 +205,9 @@ class PredictionServiceGrpcAsyncIOTransport(PredictionServiceTransport):
         )
 
         if not self._grpc_channel:
-            self._grpc_channel = type(self).create_channel(
+            # initialize with the provided callable or the default channel
+            channel_init = channel or type(self).create_channel
+            self._grpc_channel = channel_init(
                 self._host,
                 # use the credentials which are saved
                 credentials=self._credentials,
@@ -509,6 +516,86 @@ class PredictionServiceGrpcAsyncIOTransport(PredictionServiceTransport):
             )
         return self._stubs['streaming_raw_predict']
 
+    @property
+    def predict_long_running(self) -> Callable[
+            [prediction_service.PredictLongRunningRequest],
+            Awaitable[operations_pb2.Operation]]:
+        r"""Return a callable for the predict long running method over gRPC.
+
+        Returns:
+            Callable[[~.PredictLongRunningRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'predict_long_running' not in self._stubs:
+            self._stubs['predict_long_running'] = self.grpc_channel.unary_unary(
+                '/google.cloud.aiplatform.v1beta1.PredictionService/PredictLongRunning',
+                request_serializer=prediction_service.PredictLongRunningRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs['predict_long_running']
+
+    @property
+    def fetch_predict_operation(self) -> Callable[
+            [prediction_service.FetchPredictOperationRequest],
+            Awaitable[operations_pb2.Operation]]:
+        r"""Return a callable for the fetch predict operation method over gRPC.
+
+        Fetch an asynchronous online prediction operation.
+
+        Returns:
+            Callable[[~.FetchPredictOperationRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'fetch_predict_operation' not in self._stubs:
+            self._stubs['fetch_predict_operation'] = self.grpc_channel.unary_unary(
+                '/google.cloud.aiplatform.v1beta1.PredictionService/FetchPredictOperation',
+                request_serializer=prediction_service.FetchPredictOperationRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs['fetch_predict_operation']
+
+    @property
+    def invoke(self) -> Callable[
+            [prediction_service.InvokeRequest],
+            Awaitable[httpbody_pb2.HttpBody]]:
+        r"""Return a callable for the invoke method over gRPC.
+
+        Forwards arbitrary HTTP requests for both streaming and
+        non-streaming cases. To use this method,
+        [invoke_route_prefix][Model.container_spec.invoke_route_prefix]
+        must be set to allow the paths that will be specified in the
+        request.
+
+        Returns:
+            Callable[[~.InvokeRequest],
+                    Awaitable[~.HttpBody]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'invoke' not in self._stubs:
+            self._stubs['invoke'] = self.grpc_channel.unary_stream(
+                '/google.cloud.aiplatform.v1beta1.PredictionService/Invoke',
+                request_serializer=prediction_service.InvokeRequest.serialize,
+                response_deserializer=httpbody_pb2.HttpBody.FromString,
+            )
+        return self._stubs['invoke']
+
     @property
     def explain(self) -> Callable[
             [prediction_service.ExplainRequest],
@@ -651,6 +738,132 @@ class PredictionServiceGrpcAsyncIOTransport(PredictionServiceTransport):
             )
         return self._stubs['chat_completions']
 
+    @property
+    def embed_content(self) -> Callable[
+            [prediction_service.EmbedContentRequest],
+            Awaitable[prediction_service.EmbedContentResponse]]:
+        r"""Return a callable for the embed content method over gRPC.
+
+        Embed content with multimodal inputs.
+
+        Returns:
+            Callable[[~.EmbedContentRequest],
+                    Awaitable[~.EmbedContentResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'embed_content' not in self._stubs:
+            self._stubs['embed_content'] = self.grpc_channel.unary_unary(
+                '/google.cloud.aiplatform.v1beta1.PredictionService/EmbedContent',
+                request_serializer=prediction_service.EmbedContentRequest.serialize,
+                response_deserializer=prediction_service.EmbedContentResponse.deserialize,
+            )
+        return self._stubs['embed_content']
+
+    def _prep_wrapped_messages(self, client_info):
+        """ Precompute the wrapped methods, overriding the base class method to use async wrappers."""
+        self._wrapped_methods = {
+            self.predict: gapic_v1.method_async.wrap_method(
+                self.predict,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.raw_predict: gapic_v1.method_async.wrap_method(
+                self.raw_predict,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.stream_raw_predict: gapic_v1.method_async.wrap_method(
+                self.stream_raw_predict,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.direct_predict: gapic_v1.method_async.wrap_method(
+                self.direct_predict,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.direct_raw_predict: gapic_v1.method_async.wrap_method(
+                self.direct_raw_predict,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.stream_direct_predict: gapic_v1.method_async.wrap_method(
+                self.stream_direct_predict,
+                default_timeout=5.0,
+                client_info=client_info,
+            ),
+            self.stream_direct_raw_predict: gapic_v1.method_async.wrap_method(
+                self.stream_direct_raw_predict,
+                default_timeout=5.0,
+                client_info=client_info,
+            ),
+            self.streaming_predict: gapic_v1.method_async.wrap_method(
+                self.streaming_predict,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.server_streaming_predict: gapic_v1.method_async.wrap_method(
+                self.server_streaming_predict,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.streaming_raw_predict: gapic_v1.method_async.wrap_method(
+                self.streaming_raw_predict,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.predict_long_running: gapic_v1.method_async.wrap_method(
+                self.predict_long_running,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.fetch_predict_operation: gapic_v1.method_async.wrap_method(
+                self.fetch_predict_operation,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.invoke: gapic_v1.method_async.wrap_method(
+                self.invoke,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.explain: gapic_v1.method_async.wrap_method(
+                self.explain,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.count_tokens: gapic_v1.method_async.wrap_method(
+                self.count_tokens,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.generate_content: gapic_v1.method_async.wrap_method(
+                self.generate_content,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.stream_generate_content: gapic_v1.method_async.wrap_method(
+                self.stream_generate_content,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.chat_completions: gapic_v1.method_async.wrap_method(
+                self.chat_completions,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.embed_content: gapic_v1.method_async.wrap_method(
+                self.embed_content,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+         }
+
     def close(self):
         return self.grpc_channel.close()
 
