@@ -26,9 +26,12 @@ from googlecloudsdk.command_lib.compute.org_security_policies import org_securit
 import six
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
+@base.UniverseCompatible
+@base.ReleaseTracks(
+    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA
+)
 class Delete(base.DeleteCommand):
-  """Delete a Google Compute Engine organization security policy.
+  """Delete a Compute Engine organization security policy.
 
   *{command}* is used to delete organization security policies. An organization
   security policy is a set of rules that controls access to various resources.
@@ -44,7 +47,7 @@ class Delete(base.DeleteCommand):
     parser.add_argument(
         '--organization',
         help=('Organization in which the organization security policy is to be'
-              ' deleted. Must be set if SECURITY_POLICY is display name.'))
+              ' deleted. Must be set if SECURITY_POLICY is short name.'))
     parser.display_info.AddCacheUpdater(flags.OrgSecurityPoliciesCompleter)
 
   def Run(self, args):
@@ -64,8 +67,8 @@ class Delete(base.DeleteCommand):
 Delete.detailed_help = {
     'EXAMPLES':
         """\
-    To delete an organization security policy with ID ``123456789", run:
+    To delete an organization security policy with ID ``123456789'', run:
 
-      $ {command} delete 123456789
+      $ {command} 123456789
     """,
 }
