@@ -49,6 +49,14 @@ _PROVIDE_SERVICE_ACCOUNT_MESSAGE = (
     " '--impersonate-service-account' flag."
 )
 
+_INVALID_DURATION_WITH_SYSTEM_MANAGED_KEY_MESSAGE = (
+    'Max valid duration allowed is 12h when system-managed key is used. For'
+    ' longer duration, consider using the private-key-file or an account'
+    ' authorized with `gcloud auth activate-service-account`.'
+)
+
+_MAX_EXPIRATION_TIME_WITH_SYSTEM_MANAGED_KEY = 12 * 60 * 60
+
 
 @functools.lru_cache(maxsize=None)
 def _get_region_with_cache(scheme, bucket_name):
@@ -214,6 +222,7 @@ class SignUrl(base.Command):
     )
 
   def Run(self, args):
+
     key = None
     delegates = None
     delegate_chain = args.impersonate_service_account or (
@@ -238,7 +247,7 @@ class SignUrl(base.Command):
         if c_creds.IsServiceAccountCredentials(creds):
           try:
             client_id, key = sign_url_util.get_signing_information_from_json(
-                c_creds.ToJson(creds)
+                c_creds.ToJsonGoogleAuth(creds)
             )
           except ModuleNotFoundError as error:
             if 'OpenSSL' in str(error):
@@ -252,6 +261,17 @@ class SignUrl(base.Command):
         else:
           raise
 
+    # This restriction comes from the IAM SignBlob API. The SignBlob
+    # API uses a system-managed key which can guarantee validation only
+    # up to 12 hours. b/356197316
+    if (
+        key is None
+        and args.duration > _MAX_EXPIRATION_TIME_WITH_SYSTEM_MANAGED_KEY
+    ):
+      raise command_errors.Error(
+          _INVALID_DURATION_WITH_SYSTEM_MANAGED_KEY_MESSAGE
+      )
+
     # Signed URLs always hit the XML API, regardless of what API is preferred
     # for other operations.
     host = properties.VALUES.storage.gs_xml_endpoint_url.Get()
@@ -277,7 +297,8 @@ class SignUrl(base.Command):
           path = '/{}'.format(resource.storage_url.bucket_name)
         else:
           path = '/{}/{}'.format(
-              resource.storage_url.bucket_name, resource.storage_url.object_name
+              resource.storage_url.bucket_name,
+              resource.storage_url.resource_name,
           )
 
         parameters = dict(args.query_params)
